@@ -78,11 +78,14 @@ def swagger_decorator(
         def parse_simple_schema(c_schema, location):
             ret = []
             for key, value in c_schema.__dict__.get('_declared_fields').items():
-                assert type(value) in FIELDS_JSON_TYPE_MAP, '不支持的%s类型' % str(type(value))
+                values_real_types = list(set(FIELDS_JSON_TYPE_MAP) & set(value.__class__.__mro__))
+                values_real_types.sort(key=value.__class__.__mro__.index)
+                if not values_real_types:
+                    raise '不支持的%s类型' % str(type(value))
                 tmp = {
                     'in': location,
                     'name': getattr(value, 'data_key', None) or key,
-                    'type': FIELDS_JSON_TYPE_MAP.get(type(value)),
+                    'type': FIELDS_JSON_TYPE_MAP.get(values_real_types[0]),
                     'required': value.required if location != 'path' else True,
                     'description': value.metadata.get('doc', '')
                 }
@@ -122,9 +125,12 @@ def swagger_decorator(
                     if not isinstance(value.default, _Missing):
                         tmp[key]['default'] = value.default
                 else:
-                    assert type(value) in FIELDS_JSON_TYPE_MAP, '不支持的%s类型' % str(type(value))
+                    values_real_types = list(set(FIELDS_JSON_TYPE_MAP) & set(value.__class__.__mro__))
+                    values_real_types.sort(key=value.__class__.__mro__.index)
+                    if not values_real_types:
+                        raise '不支持的%s类型' % str(type(value))
                     tmp[key] = {
-                        'type': FIELDS_JSON_TYPE_MAP.get(type(value)),
+                        'type': FIELDS_JSON_TYPE_MAP.get(values_real_types[0]),
                         'description': value.metadata.get('doc', ''),
                         'required': value.required,
                     }
@@ -180,9 +186,9 @@ def swagger_decorator(
                         doc_dict.setdefault('produces', [])
                         doc_dict['produces'].extend(produces)
                         'application/xml' in produces and doc_dict['responses'][code]['schema'] and \
-                            doc_dict['responses'][code]['schema'].update(
-                                {'xml': {'name': getattr(current_schema.Meta, 'xml_root', 'xml')}}
-                            )
+                        doc_dict['responses'][code]['schema'].update(
+                            {'xml': {'name': getattr(current_schema.Meta, 'xml_root', 'xml')}}
+                        )
 
             ret_doc = """---\n""" + yaml.dump(doc_dict)
             return ret_doc
@@ -194,19 +200,21 @@ def swagger_decorator(
             path_params = request.view_args
             query_params = request.args
             form_params = request.form
-            json_params = request.json
+            json_params = request.get_json(silent=True) or {}
             header_params = request.headers
             logger.info(
                 'request params\npath params: %s\nquery params: %s\nform params: %s\njson params: %s\n',
                 path_params, query_params, form_params, json_params
             )
             logger.info('headers: %s\n', header_params)
+            request.path_schema, request.path_schema, request.form_schema = [None] * 3
+            request.json_schema, request.headers_schema = [None] * 2
             try:
-                path_schema and path_schema().load(path_params)
-                query_schema and query_schema().load(query_params)
-                form_schema and form_schema().load(form_params)
-                json_schema and json_schema().load(json_params)
-                headers_schema and headers_schema().load(dict(header_params))
+                path_schema and setattr(request, 'path_schema', path_schema().load(path_params or {}))
+                query_schema and setattr(request, 'query_schema', query_schema().load(query_params or {}))
+                form_schema and setattr(request, 'form_schema', form_schema().load(form_params or {}))
+                json_schema and setattr(request, 'json_schema', json_schema().load(json_params or {}))
+                headers_schema and setattr(request, 'headers_schema', headers_schema().load(dict(header_params)))
             except Exception as e:
                 return 'request error: %s' % ''.join(
                     [('%s: %s; ' % (x, ''.join(y))) for x, y in e.messages.items()]), 400
@@ -215,16 +223,14 @@ def swagger_decorator(
             logger.info('response data\ndata: %s\ncode: %s\nheaders: %s\n', data, code, headers)
             try:
                 if response_schema and response_schema.get(code):
-                    data = data or {}
-                    response_schema.get(code)().load(data)
+                    data = response_schema.get(code)().load(data or {})
                     r_headers_schema = getattr(response_schema.get(code).Meta, 'headers', None)
                     if r_headers_schema:
-                        r_headers_schema().load(headers or {})
-                response_schema and response_schema.get(code) and response_schema.get(code)().load(data)
+                        headers = r_headers_schema().load(headers or {})
             except Exception as e:
                 return 'response error: %s' % ''.join(
                     [('%s: %s; ' % (x, ''.join(y))) for x, y in e.messages.items()]), 400
-            return f_result
+            return data, code, headers
 
         return wrapper
 
